@@ -9,7 +9,7 @@
 #' @param cohort Vector or list specifying the cohort(s) of interest. Must be
 #'   one of "NSCLC" (Non-Small Cell Lung Cancer), "CRC" (Colorectal Cancer), or
 #'   "BrCa" (Breast Cancer), "PANC" (Pancreatic Cancer), "Prostate" (Prostate Cancer),
-#'   and "BLADDER" (Bladder Cancer).
+#'   and "BLADDER" (Bladder Cancer). This is not case sensitive.
 #' @param version Vector specifying the version of the cohort. Must match one of the
 #'   release versions available for the specified `cohort` (see `synapse_version()` for available cohort versions).
 #'   When entering multiple cohorts, it is inferred that the order of the version
@@ -22,6 +22,7 @@
 #'   specified, data are not read into the R environment.
 #' @param username 'Synapse' username
 #' @param password 'Synapse' password
+#' @param pat 'Synapse' personal access token
 #'
 #' @section Authentication:
 #' To access data, users must have a valid 'Synapse' account with permission to
@@ -34,6 +35,10 @@
 #'
 #' `set_synapse_credentials(username = "your_username", password = "your_password")`
 #'
+#' In addition to passing your 'Synapse' username and password, you may choose to set
+#' your 'Synapse' Personal Access Token (PAT) by calling:
+#'  `set_synapse_credentials(pat = "your_pat")`.
+#'
 #' If your credentials are stored as environmental variables, you do not need to
 #' call `set_synapse_credentials()` explicitly each session. To store
 #' authentication information in your environmental variables, add the following
@@ -43,8 +48,9 @@
 #' \itemize{
 #'    \item `SYNAPSE_USERNAME = <your-username>`
 #'    \item `SYNAPSE_PASSWORD = <your-password>`
+#'    \item `SYNAPSE_PAT = <your-pat>`
 #'    }
-#' Alternatively, you can pass your username and password to each individual
+#' Alternatively, you can pass your username and password or your PAT to each individual
 #' data pull function if preferred, although it is recommended that you manage
 #' your passwords outside of your scripts for security purposes.
 #'
@@ -55,6 +61,7 @@
 #'   \item \href{https://www.synapse.org/#!Synapse:syn23002641}{NSCLC v1.1-Consortium Analytic Data Guide}
 #'   \item \href{https://www.synapse.org/#!Synapse:syn53463493}{NSCLC v2.2-Consortium Analytic Data Guide}
 #'   \item \href{https://www.synapse.org/#!Synapse:syn30557304}{NSCLC v2.0-Public Analytic Data Guide}
+#'   \item \href{https://www.synapse.org/#!Synapse:syn58597690}{NSCLC v3.1-Consortium Analytic Data Guide}
 #'   \item \href{https://www.synapse.org/#!Synapse:syn53463650}{CRC v1.3-Consortium Analytic Data Guide}
 #'   \item \href{https://www.synapse.org/#!Synapse:syn31751466}{CRC v2.0-Public Analytic Data Guide}
 #'   \item \href{https://www.synapse.org/#!Synapse:syn26077313}{BrCa v1.1-Consortium Analytic Data Guide}
@@ -73,7 +80,7 @@
 #' @author Karissa Whiting, Michael Curry
 #' @export
 #'
-#' @examplesIf genieBPC::.is_connected_to_genie()
+#' @examplesIf genieBPC::.is_connected_to_genie(pat = Sys.getenv("SYNAPSE_PAT"))
 #' # Example 1 ----------------------------------
 #' # Set up 'Synapse' credentials
 #' set_synapse_credentials()
@@ -99,14 +106,40 @@
 
 pull_data_synapse <- function(cohort = NULL, version = NULL,
                               download_location = NULL,
-                              username = NULL, password = NULL) {
+                              username = NULL, password = NULL, pat = NULL) {
 
   # Check parameters ---------------------------------------------------------
 
   # Make sure credentials are available and get token ---
-  token <- .get_synapse_token(username = username, password = password)
+  token <- .get_synapse_token(username = username,
+                                       password = password,
+                                       pat = pat)
 
   # get `cohort` ---
+  if(is.null(cohort)){
+
+    cli::cli_abort("Cohort needs to be specified.
+                Use {.code synapse_version()} to see what data is available.")
+
+  }
+
+  # make cohort term not be case sensitive - will require update as new disease areas are added
+  cohort <- dplyr::case_when(
+    stringr::str_to_upper(cohort)=="NSCLC" |
+    stringr::str_to_upper(cohort)=="NON-SMALL CELL LUNG CANCER" |
+    stringr::str_to_upper(cohort)=="NON SMALL CELL LUNG CANCER" |
+    stringr::str_to_upper(cohort)=="NONSMALL CELL LUNG CANCER"~ "NSCLC",
+    stringr::str_to_upper(cohort)=="CRC" | stringr::str_to_upper(cohort)=="COLORECTAL CANCER" ~ "CRC",
+    stringr::str_to_upper(cohort)=="BRCA" | stringr::str_to_upper(cohort)=="BREAST CANCER"~ "BrCa",
+    stringr::str_to_upper(cohort)=="BLADDER" ~ "BLADDER",
+    stringr::str_to_upper(cohort)=="PANC" | stringr::str_to_upper(cohort)=="PANCREAS" ~ "PANC",
+    stringr::str_to_upper(cohort)=="PROSTATE" ~ "Prostate",
+    # last condition to avoid error message:
+    # '`cohort` must be a single string, not a character `NA`.'
+    # when an NA is fed into arg_match below
+    TRUE ~ cohort
+  )
+
   select_cohort <- rlang::arg_match(cohort, c("NSCLC", "CRC", "BrCa", "BLADDER", "PANC", "Prostate"),
     multiple = TRUE
   )
@@ -168,6 +201,10 @@ pull_data_synapse <- function(cohort = NULL, version = NULL,
       }
     }
 
+  # If consortium data requested, check that consortium access is granted for account
+  if(any(str_detect(version_num$version, "consortium"))) {
+    suppressMessages(check_genie_access(pat = token, check_consortium_access = TRUE))
+  }
 
   version_num <- version_num %>%
     dplyr::inner_join(sv, ., by = c("cohort", "version")) %>%
@@ -231,7 +268,7 @@ pull_data_synapse <- function(cohort = NULL, version = NULL,
 #' @keywords internal
 #' @export
 #'
-#' @examplesIf genieBPC::.is_connected_to_genie()
+#' @examplesIf genieBPC::.is_connected_to_genie(pat = Sys.getenv("SYNAPSE_PAT"))
 #'
 #' temp_directory <- tempdir()
 #'
